wherehouse-sdk-py
=================

A Python 2.x client for Wherehouse modules.

Centroid
--------

NetworkUtils
~~~~~~~~~~~~

Utilities for converting shapefiles into edges and nodes.

Usage
~~~~~

.. code-block:: bash

    $ python
    >>> from wherehouse.centroid import NetworkUtils
    >>> NetworkUtils.create_network_files(<path>, <path>)


Installation
------------

.. code-block:: bash

    $ pip install wherehouse


Requirements
------------

.. code-block:: bash

    $ pip install -r requirements.txt
